@@ -49,7 +49,7 @@ else:
         return ' '.join(map(pipes.quote, cmd_list))
 
 
-__version__ = '0.7.9'
+__version__ = '0.7.11'
 
 # ---------------------------------------------------------------------------
 # Top Level Variables
@@ -160,7 +160,7 @@ def create_cmdclass(prerelease_cmd=None, package_data_spec=None,
     The package data glob patterns should be relative paths from the package
     folder containing the __init__.py file, which is given as the package
     name.
-    e.g. `dict(foo=['./bar/*', './baz/**'])`
+    e.g. `dict(foo=['bar/*', 'baz/**'])`
 
     The data files directories should be absolute paths or relative paths
     from the root directory of the repository.  Data files are specified
@@ -377,7 +377,8 @@ def install_npm(path=None, build_dir=None, source_dir=None, build_cmd='build',
                 log.info('Installing build dependencies with npm.  This may '
                          'take a while...')
                 run(npm_cmd + ['install'], cwd=node_package)
-                run(npm_cmd + ['run', build_cmd], cwd=node_package)
+                if build_cmd:
+                    run(npm_cmd + ['run', build_cmd], cwd=node_package)
 
     return NPM
 
